@@ -46,7 +46,7 @@ $lang = array_merge($lang, array(
 	'ACP_AUTOMATION'			=> 'Automatizare',
 	'ACP_AVATAR_SETTINGS'		=> 'Configurări imagini asociate',
 
-	'ACP_BACKUP'				=> 'Backup',
+	'ACP_BACKUP'				=> 'Salvare (Backup)',
 	'ACP_BAN'					=> 'Banare',
 	'ACP_BAN_EMAILS'			=> 'Banare conturi e-mail',
 	'ACP_BAN_IPS'				=> 'Banare IP-uri',
@@ -325,6 +325,16 @@ $lang = array_merge($lang, array(
 	'DATABASE_SERVER_INFO'	=> 'Server bază de date',
 	'DATABASE_SIZE'			=> 'Dimensiunile bazei de date',
 
+	// Enviroment configuration checks, mbstring related
+	'ERROR_MBSTRING_FUNC_OVERLOAD'					=> 'Funcția overloading este configurată necorespunzător',
+	'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'			=> '<var>mbstring.func_overload</var> trebuie să fie setată fie 0 sau 4. Puteți verifica valoarea curentă în secțiunea <samp>PHP information</samp>.',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION'			=> 'Caracterul de codare transparentă este configurat necorespunzător',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'	=> '<var>mbstring.encoding_translation</var> trebuie să fie setată 0. Puteți verifica valoarea curentă în secțiunea <samp>PHP information</samp>.',
+	'ERROR_MBSTRING_HTTP_INPUT'						=> 'Caracterul de conversie intrare HTTP este configurat necorespunzător',
+	'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'				=> '<var>mbstring.http_input</var> trebuie să fie setată ca <samp>pass</samp>. Puteți verifica valoarea curentă în secțiunea <samp>PHP information</samp>.',
+	'ERROR_MBSTRING_HTTP_OUTPUT'					=> 'Caracterul de conversie ieșire HTTP este configurat necorespunzător',
+	'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'			=> '<var>mbstring.http_output</var> trebuie să fie setată ca <samp>pass</samp>. Puteți verifica valoarea curentă în secțiunea <samp>PHP information</samp>.',
+
 	'FILES_PER_DAY'		=> 'Fişiere ataşate pe zi',
 	'FORUM_STATS'		=> 'Statistici forum',
 
@@ -532,9 +542,9 @@ $lang = array_merge($lang, array(
 	'LOG_DISALLOW_ADD'		=> '<strong>Numele de utilizatori interzise adăugate</strong><br />» %s',
 	'LOG_DISALLOW_DELETE'	=> '<strong>Numele de utlizatori interzise şterse</strong>',
 
-	'LOG_DB_BACKUP'			=> '<strong>Backup bază de date</strong>',
-	'LOG_DB_DELETE'			=> '<strong>Backup bază de date şters</strong>',
-	'LOG_DB_RESTORE'		=> '<strong>Backup bază de date restaurat</strong>',
+	'LOG_DB_BACKUP'			=> '<strong>Copie siguranță bază de date</strong>',
+	'LOG_DB_DELETE'			=> '<strong>Copie siguranță bază de date ştearsă</strong>',
+	'LOG_DB_RESTORE'		=> '<strong>Copie siguranță bază de date restaurată</strong>',
 
 	'LOG_DOWNLOAD_EXCLUDE_IP'	=> '<strong>IP-uri/nume de hosturi excluse din lista de descărcare</strong><br />» %s',
 	'LOG_DOWNLOAD_IP'			=> '<strong>IP-uri/nume de hosturi adăugate în lista de descărcare</strong><br />» %s',
