@@ -165,6 +165,7 @@ $lang = array_merge($lang, array(
     'EMPTY_MESSAGE_SUBJECT'             => 'Trebuie să specificaţi un subiect când compuneţi un mesaj nou.',
     'ENABLED'                           => 'Activat',
     'ENCLOSURE'                         => 'Împrejmuire',
+	'ENTER_USERNAME'					=> 'Introduceți nume utilizator',
     'ERR_CHANGING_DIRECTORY'            => 'Nu s-a putut schimba directorul.',
     'ERR_CONNECTING_SERVER'             => 'Eroare în efectuarea conexiunii către server.',
     'ERR_JAB_AUTH'                      => 'Nu s-a putut autentifica la serverul de Jabber.',
@@ -200,6 +201,7 @@ $lang = array_merge($lang, array(
     'FORUM_RULES_LINK'      => 'Accesează link-ul pentru a putea vedea regulile forumului',
     'FROM'                  => 'de la',
     'FSOCK_DISABLED'        => 'Operaţiunea nu a putut fi finalizată deoarece funcţia <var>fsockopen</var> a fost dezactivată sau serverul care este interogat nu a fost găsit.',
+	'FSOCK_TIMEOUT'			=> 'Nu am putut ajunge la serverul din rețea.',
 
     'FTP_FSOCK_HOST'                => 'Host FTP',
     'FTP_FSOCK_HOST_EXPLAIN'        => 'Serverul FTP folosit pentru conexiunea cu siteul dumneavoastră.',
@@ -387,8 +389,8 @@ $lang = array_merge($lang, array(
     'NO_ONLINE_USERS'           => 'Niciun utilizator înregistrat',
     'NO_POSTS'                  => 'Niciun mesaj',
     'NO_POSTS_TIME_FRAME'       => 'Nu există niciun mesaj în interiorul acestui subiect pentru perioada de timp selectată.',
-    'NO_FEED_ENABLED'			=> 'Fluxurile nu sunt disponibile penru acest forum.',
-	  'NO_FEED'					=> 'Fluxul solicitat nu este disponibil.',
+    'NO_FEED_ENABLED'			=> 'Fluxurile nu sunt disponibile pentru acest forum.',
+	'NO_FEED'					=> 'Fluxul solicitat nu este disponibil.',
     'NO_SUBJECT'                => 'Niciun subiect specificat',                 // Used for posts having no subject defined but displayed within management pages.
     'NO_SUCH_SEARCH_MODULE'     => 'Backend-ul de căutare specificat nu există.',
     'NO_SUPPORTED_AUTH_METHODS' => 'Nu există nicio metodă de autentificare.',
@@ -649,6 +651,10 @@ $lang = array_merge($lang, array(
     'UNREAD_PMS'            => '<strong>%d</strong> mesaje necitite',
     'UNREAD_POST'         => 'Mesaj necitit',
     'UNREAD_POSTS'         => 'Mesaje necitite',
+	'UNWATCH_FORUM_CONFIRM'		=> 'Sunteți sigur că doriți să vă dezabonați de la acest forum?',
+	'UNWATCH_FORUM_DETAILED'	=> 'Sunteți sigur că doriți să vă dezabonați de la forumul “%s”?',
+	'UNWATCH_TOPIC_CONFIRM'		=> 'Sunteți sigur că doriți să vă dezabonați de la acest subiect?',
+	'UNWATCH_TOPIC_DETAILED'	=> 'Sunteți sigur că doriți să vă dezabonați de la subiectul “%s”?',
     'UNWATCHED_FORUMS'      => 'Nu mai sunteţi abonat la forumurile selectate.',
     'UNWATCHED_TOPICS'      => 'Nu mai sunteţi abonat subiectele selectate.',
     'UNWATCHED_FORUMS_TOPICS'   => 'Nu mai sunteţi abonat la intrările selectate.',
@@ -696,6 +702,10 @@ $lang = array_merge($lang, array(
 
     'WARNINGS'          => 'Avertismente',
     'WARN_USER'         => 'Avertizează utilizator',
+	'WATCH_FORUM_CONFIRM'	=> 'Sunteți sigur că doriți să vă abonați la acest forum?',
+	'WATCH_FORUM_DETAILED'	=> 'Sunteți sigur că doriți să vă abonați la forumul “%s”?',
+	'WATCH_TOPIC_CONFIRM'	=> 'Sunteți sigur că doriți să vă abonați la acest subiect?',
+	'WATCH_TOPIC_DETAILED'	=> 'Sunteți sigur că doriți să vă abonați la subiectul “%s”?',
     'WELCOME_SUBJECT'   => 'Bine aţi venit în forumurile %s',
     'WEBSITE'           => 'Site web',
     'WHOIS'             => 'Cine este',
